@@ -4,7 +4,7 @@ package Class::Workflow::YAML;
 use Moose;
 
 use Class::Workflow;
-use YAML (); # not YAML::Syck, for !perl/code loading
+use YAML ();
 
 has workflow_key => (
 	isa => "Str",
@@ -12,21 +12,29 @@ has workflow_key => (
 	default => "workflow",
 );
 
-use tt;
-[% FOR type IN ["string", "file"] %]
-sub load_[% type %] {
+sub load_string {
 	my ( $self, $data ) = @_;
-	my $res = $self->localize_yaml_env( _load_[% type %] => $data );
+	my $res = $self->localize_yaml_env( _load_string => $data );
 	my $workflow = $self->empty_workflow;
 	$self->inflate_hash( $workflow, $res );
 }
 
-sub _load_[% type %] {
+sub load_file {
+        my ( $self, $data ) = @_;
+        my $res = $self->localize_yaml_env( _load_file => $data );
+        my $workflow = $self->empty_workflow;
+        $self->inflate_hash( $workflow, $res );
+}
+
+sub _load_string {
 	my ( $self, $data ) = @_;
-	YAML::Load[% IF type == "file" %]File[% END %]( $data );
+	YAML::Load( $data );
+}
+
+sub _load_file {
+        my ( $self, $data ) = @_;
+        YAML::LoadFile( $data );
 }
-[% END %]
-no tt;
 
 sub localize_yaml_env {
 	my ( $self, $method, @args ) = @_;
@@ -113,7 +121,7 @@ Class::Workflow::YAML - Load workflow definitions from YAML files.
 	          to_state: closed
 	        - name    : unresolved
 	          to_state: open
-	    - name: unassigned:
+	    - name: unassigned
 	      transitions:
 	        - name    : take
 	          to_state: open
@@ -167,14 +175,10 @@ Calls C<< Class::Workflow->new >>
 
 =item localize_yaml_env
 
-A wrapper method to locally set C<$YAML::UseCode> to 1.
+A wrapper method to locally set C<$YAML::Syck::UseCode> to 1.
 
 =back
 
-=head1 TODO
-
-Switch to L<YAML::Syck> once it gets support for C<!perl/code> nodes.
-
 =head1 SEE ALSO
 
 L<Class::Workflow>, L<YAML>
